/*******************************************************************************
**  DAVE App Name : LIBS       App Version: 1.0.22               
**  This file is generated by DAVE, User modification to this file will be    **
**  overwritten at the next code generation.                                  **
*******************************************************************************/


/*CODE_BLOCK_BEGIN[MOTORLIB.c]*/
/*******************************************************************************
 Copyright (c) 2011, Infineon Technologies AG                                 **
 All rights reserved.                                                         **
                                                                              **
 Redistribution and use in source and binary forms, with or without           **
 modification,are permitted provided that the following conditions are met:   **
                                                                              **
 *Redistributions of source code must retain the above copyright notice,      **
 this list of conditions and the following disclaimer.                        **
 *Redistributions in binary form must reproduce the above copyright notice,   **
 this list of conditions and the following disclaimer in the documentation    **
 and/or other materials provided with the distribution.                       **
 *Neither the name of the copyright holders nor the names of its contributors **
 may be used to endorse or promote products derived from this software without**
 specific prior written permission.                                           **
                                                                              **
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"  **
 AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE    **
 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE   **
 ARE  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE   **
 LIABLE  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR         **
 CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF         **
 SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS    **
 INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN      **
 CONTRACT, STRICT LIABILITY,OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)       **
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE   **
 POSSIBILITY OF SUCH DAMAGE.                                                  **
                                                                              **
 To improve the quality of the software, users are encouraged to share        **
 modifications, enhancements or bug fixes with Infineon Technologies AG       **
 dave@infineon.com).                                                          **
                                                                              **
********************************************************************************
**                                                                            **
**                                                                            **
** PLATFORM : Infineon XMC4000 Series /XMC1000 Series                         **
**                                                                            **
** COMPILER : Compiler Independent                                            **
**                                                                            **
** AUTHOR   : App Developer                                                   **
**                                                                            **
** MAY BE CHANGED BY USER [yes/no]: Yes                                       **
**                                                                            **
** MODIFICATION DATE : 26 Nov, 2013                                           **
**                                                                            **
*******************************************************************************/

/*******************************************************************************
**                       Author(s) Identity                                   **
********************************************************************************
**                                                                            **
** Initials     Name                                                          **
** ---------------------------------------------------------------------------**
** PA           Dave App Developer                                            **
**                                                                            **
*******************************************************************************/
/**
 * @file  MOTORLIB.c
 *
 * @brief This file contains implementations of all Public and Private functions
 *        of Motor control library.
 *
 */
 /* Revision History
 * 03 Apr 2013   v1.0.0    Initial version
 * 25 Apr 2013   v1.0.2    Added support for XMC1302
 * 29  May 2013  v1.0.12   Added FOC support for XMC1302
 * 21 June 2013  v1.0.14   Added support for XMC4400 and XMC4200 device
 * 24 Jul 2013   v1.0.18   Added FOC support for XMC4400 device
 * 26 Nov 2013   v1.0.22   Added FOC support for XMC45 & XMC42 device
 */  
/*******************************************************************************
**                      Include Files                                         **
*******************************************************************************/
#include <DAVE3.h>
#include "../../inc/LIBS/MOTORLIB.h"
/*******************************************************************************
**                      Private Macro Definitions                             **
*******************************************************************************/
/**
 * @cond INTERNAL_DOCS
 */
/**
  * @ingroup MOTORLIBS_privatefunc
  * @{
  */
#ifdef USE_MOTORLIBS  
/*****************************************************************************
**                      Private Type Definitions                            **
******************************************************************************/
/*****************************************************************************
 *                 Private Function declarations                             *
 *****************************************************************************/
/**
 * @}
 */
/*******************************************************************************
**                      Imported Global Variables                             **
*******************************************************************************/

/*******************************************************************************
**                      Global Constant Definitions                           **
*******************************************************************************/

/*******************************************************************************
**                      Global Variable Definitions                           **
*******************************************************************************/
const int32_t e[23] = {0x20000000, 0x12E4051D, 0x9FB385B, 0x51111D4, 0x28B0D43, 0x145D7E1, 0xA2F61E, 0x517C55, 0x28BE53, 0x145F2E, 0xA2F98, 0x517CC, 0x28BE6, 0x145F3, 0xA2F9, 0x517C, 0x28BE, 0x145F, 0xA2F, 0x517, 0x28B, 0x145, 0xA2};
/*******************************************************************************
**                      Private Constant Definitions                          **
*******************************************************************************/

/*******************************************************************************
**                 Function like macro definitions                            **
*******************************************************************************/

/*******************************************************************************
**                      Private Function Definitions                          **
*******************************************************************************/
/*******************************************************************************
**                      Public Function Definitions                           **
*******************************************************************************/


uint32_t MOTORLIBS_Car2Pol(int32_t x,int32_t y, int16_t *Angle)
{
  uint8_t CordicCount;
  int32_t dx,flag = 0, tempAngle = 0,CORDX =x,CORDY=y;
  if(CORDX < 0)
  {
    CORDX = -CORDX;
  flag = 1;
  }
  for (CordicCount = 0; CordicCount < CORDIC_ITERATIONS; CordicCount++)
  {
    dx =  CORDX >> CordicCount;
  if( CORDY > 0 )
  {
    CORDX += CORDY >> CordicCount;
    CORDY -= dx;
      tempAngle -= e[CordicCount];
    }
  else
  {
    CORDX -= CORDY >> CordicCount;
    CORDY += dx;
    tempAngle += e[CordicCount];
  }
  }

  *Angle = (int16_t)(((flag) ?  tempAngle + 0x80000000: -tempAngle)>>16);
  return (CORDX>>MOTORLIBS_MPS_DIVBY1);
}
/**
 * This function is the implementation of Polar to cartesian Transformation.
 */
int32_t MOTORLIBS_Pol2Car(int16_t Angle,uint32_t Amplitude, int32_t *x)
{
  uint8_t CordicCount, flag=0;
  int32_t dx,CORDX =Amplitude,CORDY=0,tempAngle = Angle<<16;

  if (MOTORLIBS_ABS(tempAngle) > 0x40000000U)
  {
    tempAngle = 0x80000000 - tempAngle;
    CORDX = -CORDX;
  flag = 1;
  }

  for (CordicCount = 0; CordicCount < CORDIC_ITERATIONS; CordicCount++)
  {
    dx = CORDX>>CordicCount;
    if(tempAngle > 0)
    {
      CORDX -= CORDY>>CordicCount;
      CORDY += dx;
      tempAngle -= e[CordicCount];
    }
    else
    {
      CORDX += CORDY>>CordicCount;
      CORDY -= dx;
      tempAngle += e[CordicCount];
    }
  }
  *x = CORDX>>MOTORLIBS_MPS_DIVBY1;
  return(flag? -CORDY>>MOTORLIBS_MPS_DIVBY1: CORDY>>MOTORLIBS_MPS_DIVBY1);
}
/**
 * This function is the implementation of park transform.
 */
int32_t MOTORLIBS_ParkTransform(int32_t Ialpha,int32_t Ibeta,int16_t Angle,int32_t *Iq)
{
  uint8_t CordicCount, flag=0;
  int32_t dx,CORDX =Ibeta,CORDY=Ialpha,tempAngle = Angle<<16;;

  if ( MOTORLIBS_ABS(tempAngle) > 0x40000000U)
  {
    tempAngle = 0x80000000 - tempAngle;
    CORDX = -CORDX;
    flag = 1;
  }


  for (CordicCount = 0; CordicCount < CORDIC_ITERATIONS; CordicCount++)
  {
    dx = CORDX>>CordicCount;

    if(tempAngle > 0)
    {
      CORDX -= CORDY>>CordicCount;
      CORDY += dx;
      tempAngle -= e[CordicCount];
    }
    else
    {
      CORDX += CORDY>>CordicCount;
      CORDY -= dx;
      tempAngle += e[CordicCount];
    }
  }
  *Iq = CORDX>>MOTORLIBS_MPS_DIVBY2;
  return(flag? -CORDY>>MOTORLIBS_MPS_DIVBY2: CORDY>>MOTORLIBS_MPS_DIVBY2);
}
/**
 * This function is the implementation of Inverse park transform.
 * Valpha  = k/4*(Vd*cos(Anlge)- Vq*sin(Angle))
 * Vbeta   = k/4*(Vd*sin(Anlge)+Vq*cos(Angle))
 */
int32_t MOTORLIBS_IParkTransform(int32_t Vd,int32_t Vq,int16_t Angle,int32_t *Vbeta)
{
  uint8_t CordicCount, flag=0;
  int32_t dx,CORDX =Vd,CORDY=Vq,tempAngle = Angle<<16;;

  if ( MOTORLIBS_ABS(tempAngle) > 0x40000000U)
  {
    tempAngle = 0x80000000 - tempAngle;
    CORDX = -CORDX;
    flag = 1;
  }


  for (CordicCount = 0; CordicCount < CORDIC_ITERATIONS; CordicCount++)
  {
    dx = CORDX>>CordicCount;

    if(tempAngle > 0)
    {
      CORDX -= CORDY>>CordicCount;
      CORDY += dx;
      tempAngle -= e[CordicCount];
    }
    else
    {
      CORDX += CORDY>>CordicCount;
      CORDY -= dx;
      tempAngle += e[CordicCount];
    }
  }
  *Vbeta =flag? -CORDY>>MOTORLIBS_MPS_DIVBY4: CORDY>>MOTORLIBS_MPS_DIVBY4;
  return( CORDX>>MOTORLIBS_MPS_DIVBY4);
}

/**
 * This function is the implementation of Clarke transform using 2 Phase current.
 */

int32_t MOTORLIBS_ClarkTransform(int32_t Phase_A, int32_t Phase_B, int32_t *Ialpha)
{
  *Ialpha  = (int32_t)(Phase_A >>MOTORLIBS_CLARKESCALE);
  return  (int32_t)(((Phase_A + 2*Phase_B)*(MOTORLIBS_INVSQRT3))>>(15+MOTORLIBS_CLARKESCALE));
}
/**
 * This function is the implementation of Clarke transform using 3 Phase current.
 */
int32_t MOTORLIBS_ClarkTransform2(int32_t Phase_A, int32_t Phase_B, int32_t Phase_C, int32_t *Ialpha )
{
  *Ialpha  = (int32_t)(Phase_A >>MOTORLIBS_CLARKESCALE);
  return (int32_t)(((Phase_B-Phase_C)*(MOTORLIBS_INVSQRT3))>>(15+MOTORLIBS_CLARKESCALE));
}

/**
 * This function is the implementation of PI controller. 
 */
void MOTORLIBS_PIController
(
    MOTORLIBS_PIHandleType* HdlPtr,
    int32_t RefValue,
    int32_t ActValue
)
{
  int32_t Output=0;
  /* yn(k+1)= yn(k)   + ki * e(k) */
  HdlPtr->Ibuf += (int32_t) ((int32_t)HdlPtr->Ki) * (RefValue-ActValue);

  /* Checking the buffer limits in the range of Yimin to Yimax */
  HdlPtr->Ibuf = MOTORLIBS_MIN_MAX_LIMIT(((int32_t)HdlPtr->Ibuf),((int32_t)HdlPtr->Yimax),((int32_t)HdlPtr->Yimin));

  /* y(k+1) = yn(k+1) + kp * e(k) * 64 */
  Output=  ((int32_t) ((int32_t)HdlPtr->Kp) * (RefValue-ActValue));

  Output  =  (HdlPtr->Ibuf>>MOTORLIBS_PI_KISCALE) +(Output>>MOTORLIBS_PI_KPSCALE);
  
  /* Checking the buffer limits in the range of Ymin to Ymax */
  HdlPtr->PiOutVal= MOTORLIBS_MIN_MAX_LIMIT(((int32_t)(Output)),((int32_t)HdlPtr->Ymax),((int32_t)HdlPtr->Ymin));

}
/**
 * This function is the implementation of PT1 filter. 
 */
void MOTORLIBS_PT1Controller
(
   MOTORLIBS_PT1HandleType* HdlPtr,
   int32_t ActValue
)
{
  int32_t TempBuff;
  /* yn+1=yn + z1*(x - yn) */
  TempBuff = HdlPtr->PT1buf + HdlPtr->Z1*(ActValue - (HdlPtr->PT1buf>>16));
  /* Checking the buffer limits in the range of Ymin to Ymax */
  HdlPtr->PT1buf = MOTORLIBS_MIN_MAX_LIMIT((TempBuff),(HdlPtr->Ymax),(HdlPtr->Ymin));
  HdlPtr->PT1OutVal = (HdlPtr->PT1buf>>16);
}
/**
 * This function is the implementation of PT12 filter. 
 */
void MOTORLIBS_PT12Controller
(
   MOTORLIBS_PT1HandleType* HdlPtr,
   int32_t ActValue
)
{ 
  int32_t TempBuff;
  /* yn+1=yn + z1*x - z2*yn; */
  TempBuff = HdlPtr->PT1buf + ( (HdlPtr->Z1* ActValue) - (HdlPtr->Z2*(HdlPtr->PT1buf>>16)));
   
  /* Checking the buffer limits in the range of Ymin to Ymax */
  HdlPtr->PT1buf = MOTORLIBS_MIN_MAX_LIMIT((TempBuff),(HdlPtr->Ymax),(HdlPtr->Ymin));

  HdlPtr->PT1OutVal = (HdlPtr->PT1buf>>16);    
} 

#endif 

/**
 * @endcond
 */
/*CODE_BLOCK_END*/

